import React, { useEffect, useState } from "react";
import { retrieveData } from "./service";
import './autocomplete.css'
import TextField from "@mui/material/TextField";
import Autocomplete from "@mui/material/Autocomplete";
import CircularProgress from "@mui/material/CircularProgress";

export const ReactBatchAutocomplete = ({
  placeholder = "Enter your address",
  notFoundText = "Not found data",
  onSelect,
  suggestionList,
  handleError,
  apiKey,
  domainServer
}) => {
  const [search, setSearch] = useState("");
  const [searchQuery, setSearchQuery] = useState("");
  const [open, setOpen] = useState(false);
  const [options, setOptions] = useState([]);
  const [loading, setLoading] = useState(false);
  useEffect(() => {
    const timeout = setTimeout(() => {
      setSearchQuery(search);
    }, 700);

    return () => {
      clearTimeout(timeout);
    };
  }, [search]);

  useEffect(async () => {
    if (
      searchQuery.length > 2 &&
      options?.filter((item) => item.name === searchQuery)?.length === 0
    ) {
      try {
        setLoading(true);
        setOpen(false);
        let data = await retrieveData(apiKey, domainServer, searchQuery);
        if (data?.status?.code !== 200) {
          handleError?.(data?.status);
        } else {
          setOptions(data?.result?.suggestions);
          suggestionList?.(data?.result?.suggestions);
          setOpen(true);
        }
        setLoading(false);
      } catch (e) {
        handleError?.(e);
        setLoading(false);
      }
    } else {
      setOptions([]);
    }
  }, [searchQuery]);
  return (
    <div className="autocomplete-wrapper">
    <Autocomplete
      disablePortal
      className="custom-autocomplete"
      open={open}
      onOpen={() => {
        search.length > 2 && setOpen(true);
      }}
      onClose={() => {
        setOpen(false);
      }}
      classes={{paper: "test"}}
      onInputChange={(event, value) => {
        setSearch(value);
      }}
      getOptionLabel={(option) => option.name}
      onChange={(event, data) => onSelect?.(data)}
      inputValue={search}
      options={options}
      noOptionsText={notFoundText}
      renderInput={(params) => (
        <TextField
          {...params}
          hiddenLabel
          placeholder={placeholder}
          id="filled-hidden-label-normal"
          InputProps={{
            ...params.InputProps,
            endAdornment: (
              <>
                {loading ? (
                  <CircularProgress className="spinner" size={20} />
                ) : null}
                {params.InputProps.endAdornment}
              </>
            ),
          }}
        />
      )}
      renderOption={(props, option) => {
        let name = option.name;
        return (
          <div {...props}>
            <div className="auto-wrapper">
              <div className="img-wrap" />
              <div className="text-content">
                <strong>{name.substr(0, search.length)}</strong>
                {name.substr(search.length)}
              </div>
            </div>
          </div>
        );
      }}
    />
    </div>
  );
};

const data = [
  {
      "_id": "e90a8aedece543394f52aaebad7011b0",
      "city": "jackson",
      "state": "wy",
      "zip": "83001",
      "name": "83001 Jackson, WY",
      "type": "zip"
  },
  {
      "_id": "753c814e4777bb333fa4fdbe99d71a2e",
      "city": "jackson",
      "state": "wy",
      "zip": "83002",
      "name": "83002 Jackson, WY",
      "type": "zip"
  },
  {
      "_id": "faaaec10ac062cc674e7ccb46c92ef47",
      "address": "83000",
      "city": "florence",
      "state": "sc",
      "name": "83000, Florence, SC",
      "type": "formatted-street"
  },
  {
      "_id": "920b1bbe67ad74737d8da3d5c4171a32",
      "linkedEntityId": "kuNjWu7KrzsZiiX",
      "address": "8300 monticello st",
      "city": "covington",
      "state": "ga",
      "zip": "30014",
      "name": "8300 Monticello St, Covington, GA 30014",
      "type": "address"
  },
  {
      "_id": "9939e336ef47fca8da3b9fc52767968a",
      "linkedEntityId": "0D342Ea8RzzmUdY",
      "address": "8300 nantucket cir",
      "city": "owens cross roads",
      "state": "al",
      "zip": "35763",
      "name": "8300 Nantucket Cir, Owens Cross Roads, AL 35763",
      "type": "address"
  }
]
